
<div class="modal-header">
  <button type="button" ng-click="$dismiss()" class="close"><span aria-hidden="true">×</span><span class="sr-only">{{'dialog_close' | tr}}</span></button>
  <h4 class="modal-title">{{'options_modalHeader_replaceProfile' | tr}}</h4>
</div>
<div class="modal-body">
  <p omega-html="&quot;options_replaceProfileConfirm&quot; | tr:[profileSelect(&quot;fromName&quot;), profileSelect(&quot;toName&quot;)]"></p>
  <div class="well"><span omega-profile-inline="profileByName(fromName)" options="options" disp-name="dispNameFilter"></span> <span class="glyphicon glyphicon-chevron-right"></span> <span omega-profile-inline="profileByName(toName)" options="options" disp-name="dispNameFilter"></span>
  </div>
  <div omega-html="'options_replaceProfileHelp' | tr:[$profile('profileByName(fromName)'), $profile('profileByName(toName)')]" class="help-block"></div>
</div>
<div class="modal-footer">
  <button ng-click="$dismiss()" class="btn btn-default">{{'dialog_cancel' | tr}}</button>
  <button type="button" ng-click="$close({fromName: fromName, toName: toName})" class="btn btn-warning">{{'options_replaceProfile' | tr}}</button>
</div>