
<div class="modal-header">
  <button type="button" ng-click="$dismiss()" class="close"><span aria-hidden="true">×</span><span class="sr-only">{{'dialog_close' | tr}}</span></button>
  <h4 class="modal-title">{{'options_modalHeader_resetRules' | tr}}</h4>
</div>
<div class="modal-body">
  <p>{{'options_resetRulesConfirm' | tr}}</p>
  <div class="well"><span omega-profile-inline="ruleProfile" disp-name="dispNameFilter" options="options"></span></div>
</div>
<div class="modal-footer">
  <button ng-click="$dismiss()" class="btn btn-default">{{'dialog_cancel' | tr}}</button>
  <button type="button" ng-click="$close(&quot;ok&quot;)" class="btn btn-warning">{{'options_resetRules' | tr}}</button>
</div>