
<div class="modal-header">
  <button type="button" ng-click="$dismiss()" class="close"><span aria-hidden="true">×</span><span class="sr-only">{{'dialog_close' | tr}}</span></button>
  <h4 class="modal-title">{{'options_modalHeader_welcome' | tr}}</h4>
</div>
<div class="modal-body">
  <p ng-show="upgrade">{{'options_welcomeUpgrade' | tr}}</p>
  <p ng-show="upgrade">{{'options_welcomeUpgradeGuide' | tr}}</p>
  <p ng-show="!upgrade">{{'options_welcomeNormal' | tr}}</p>
  <p ng-show="!upgrade">{{'options_welcomeNormalGuide' | tr}}</p>
</div>
<div class="modal-footer">
  <button ng-click="$close(&quot;skip&quot;)" class="btn btn-default">{{'options_guideSkip' | tr}}</button>
  <button type="button" ng-click="$close(&quot;show&quot;)" class="btn btn-primary">{{'options_guideNext' | tr}}</button>
</div>