
<div class="modal-header">
  <button type="button" ng-click="$dismiss()" class="close"><span aria-hidden="true">×</span><span class="sr-only">{{'dialog_close' | tr}}</span></button>
  <h4 class="modal-title">{{'options_modalHeader_resetOptions' | tr}}</h4>
</div>
<div class="modal-body">
  <p class="text-danger">{{'options_resetOptionsConfirm' | tr}}</p>
</div>
<div class="modal-footer">
  <button ng-click="$dismiss()" class="btn btn-default">{{'dialog_cancel' | tr}}</button>
  <button type="button" ng-click="$close(&quot;ok&quot;)" class="btn btn-danger">{{'options_reset' | tr}}</button>
</div>